taurenmd
========

.. start-description

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3551990.svg
    :target: https://doi.org/10.5281/zenodo.3551990
    :alt: Zenodo

.. image:: https://img.shields.io/readthedocs/taurenmd/latest?label=Read%20the%20Docs
    :target: https://taurenmd.readthedocs.io/en/latest/index.html
    :alt: Read the Docs (latest)

.. image:: https://img.shields.io/travis/joaomcteixeira/taurenmd/master?label=TravisCI
    :target: https://travis-ci.org/joaomcteixeira/taurenmd
    :alt: Travis master branch

.. image:: https://codecov.io/gh/joaomcteixeira/taurenmd/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/joaomcteixeira/taurenmd
    :alt: Codecov master branch

.. image:: https://img.shields.io/coveralls/github/joaomcteixeira/taurenmd/master?label=COVERALLS&logo=COVERALLS
    :target: https://coveralls.io/github/joaomcteixeira/taurenmd
    :alt: Coveralls master

.. image:: https://api.codacy.com/project/badge/Grade/147029f2635e4e62bf670efdef728c28
    :target: https://www.codacy.com/manual/joaomcteixeira/taurenmd?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=joaomcteixeira/taurenmd&amp;utm_campaign=Badge_Grade
    :alt: Codacy

.. image:: https://api.codeclimate.com/v1/badges/d69e2e9866338d88955c/maintainability
   :target: https://codeclimate.com/github/joaomcteixeira/taurenmd
   :alt: Code Climate

.. image:: https://img.shields.io/codeclimate/tech-debt/joaomcteixeira/taurenmd?label=Code%20Climate%20tech%20debt
    :target: https://codeclimate.com/github/joaomcteixeira/taurenmd
    :alt: Code Climate technical debt

.. image:: https://img.shields.io/pypi/v/taurenmd.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/taurenmd

.. image:: https://img.shields.io/pypi/wheel/taurenmd.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/taurenmd

.. image:: https://img.shields.io/pypi/pyversions/taurenmd.svg
    :alt: Supported versions
    :target: https://pypi.org/project/taurenmd

.. image:: https://img.shields.io/github/commits-since/joaomcteixeira/taurenmd/v0.7.2/master
    :alt: Commits since latest release
    :target: https://github.com/joaomcteixeira/taurenmd/compare/v0.7.2...master


**A command-line interface for analysis routines in Molecular Dynamics.**

**Taurenmd** provides an easy, flexible and extensible, interface for the most common (and not so common) routines of analysis and representation of Molecular Dynamics (MD) data.

It bridges the gap between the highly complex (and powerful) Python libraries available for analysis of MD data and the *non-developer* users that lack the programming skills to use those libraries thoroughly. But not only, **taurenmd** also facilitates high throughput operations, even to those proficient *devs*, because complex executions are reduced to a single argument-rich command line.

**Taurenmd** wraps around feature-rich and powerful MD analysis libraries such as `MDAnalysis <https://www.mdanalysis.org/>`_ and `MDTraj <http://mdtraj.org>`_ (but not only), combining them to extract the best of *those worlds*. We use these libraries to access and extract MD data and calculate observables, and we have also added our own routines of analysis when needed.

With this said, **taurenmd** aims to be a flexible and extensible peace of software, built as simple and modular as we can think of, to *agile* the incorporation of new functionalities as needed.

**taurenmd** aims to be a command-line user-directed interface, but its core functions are openly available and distributed in the library architecture. Currently, there are already several *commands* available, some that perform only single tasks, while others allow complex setups, all are *one-liners*.

.. end-description

Documentation
=============

**taurenmd** full documentation is available at: https://taurenmd.readthedocs.io, read there:

#. how to install
#. usage
#. citing
#. *etc...*

